Learn R Programming

woeR (version 0.2.1)

apply_woe: Weight of Evidence based segmentation of a variable

Description

This function applies the binning generated from woe_binning to new data

Usage

apply_woe(df, woe_object)

Arguments

df

A data frame. The variable names and types need to be identical to the ones passed to woe_binning

woe_object

Output object from woe_binning function

Value

Input data frame is returned with two new columns - bin & woe

Examples

Run this code
# NOT RUN {
library(smbinning)
# }
# NOT RUN {
woe_object <- woe_binning(smbsimdf1, "cbs1", "fgood", initial_bins = 10)
out <- apply_woe(smbsimdf1, woe_object)
#Above example to create and apply woe segmentation
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab